@@ -227,9 +227,7 @@ def _distance(i, j, Al, Bl, An, Bn, Anames, Bnames, cost_matrix, operations):
                         operations[x+ioff][y+joff]
 
 
-def _dist_graph_list(graph1, graph2, exclude_types=[], render_to=None, dpi=800):
-    tree1 = core.alex_graph_to_tree(graph1, exclude_types=exclude_types)
-    tree2 = core.alex_graph_to_tree(graph2, exclude_types=exclude_types)
+def _dist_graph_list(tree1, tree2, exclude_types=[], render_to=None, dpi=800):
     cost, operations = ted(tree1, tree2)
     if render_to is not None:
         print("Done computing distance. Rendering image")
@@ -251,20 +249,26 @@ def _dist_graph_list(graph1, graph2, exclude_types=[], render_to=None, dpi=800):
     return cost, operations
 
 
+from alex.annotators import param_count
+
 def diff(network_config_1,
          network_config_2,
          render_to=None,
          dpi=800):
     graph_list1 = dsl_parser.parse(network_config_1)
     graph_list2 = dsl_parser.parse(network_config_2)
-    graph1 = dsl_parser.list_to_graph(graph_list1)
-    graph2 = dsl_parser.list_to_graph(graph_list2)
-    tree_full1 = core.alex_graph_to_tree(graph1, naive=False)
-    tree_full2 = core.alex_graph_to_tree(graph2, naive=False)
+    # Do not include dimensionality in diff
+    # graph1 = dsl_parser.list_to_graph(graph_list1)
+    # graph2 = dsl_parser.list_to_graph(graph_list2)
+    # tree_full1 = core.alex_graph_to_tree(graph1, naive=False)
+    # tree_full2 = core.alex_graph_to_tree(graph2, naive=False)
+    # Include dimensionality in diff
+    tree_full1 = param_count.ParamCount(network_config_1).annotate_tree()
+    tree_full2 = param_count.ParamCount(network_config_2).annotate_tree()
 
     operations = []
     cost = 0
-    for block in ["data", "component", "loss", "optimizer"]:
+    for block in ["data", "model", "loss", "optimizer"]:
 
         graph_list1_block = list(filter(lambda x: x["meta"]["block"]==block, graph_list1))
         graph_list2_block = list(filter(lambda x: x["meta"]["block"]==block, graph_list2))
@@ -302,11 +306,18 @@ def dist(network_config_1,
          exclude_types=[],
          dpi=800):
     graph_list1 = dsl_parser.parse(network_config_1)
-    graph1 = dsl_parser.list_to_graph(graph_list1)
     graph_list2 = dsl_parser.parse(network_config_2)
-    graph2 = dsl_parser.list_to_graph(graph_list2)
-    cost, operations = _dist_graph_list(graph1,
-                                        graph2,
+    # Do not include dimensionality in dist
+    # graph1 = dsl_parser.list_to_graph(graph_list1)
+    # graph2 = dsl_parser.list_to_graph(graph_list2)
+    # tree1 = core.alex_graph_to_tree(graph1, exclude_types=exclude_types)
+    # tree2 = core.alex_graph_to_tree(graph2, exclude_types=exclude_types)
+    # Include dimensionality in dist
+    tree1 = param_count.ParamCount(graph_list1).annotate_tree()
+    tree2 = param_count.ParamCount(graph_list2).annotate_tree()
+
+    cost, operations = _dist_graph_list(tree1,
+                                        tree2,
                                         exclude_types=exclude_types,
                                         render_to=render_to,
                                         dpi=dpi)
@@ -327,15 +338,19 @@ def matched_ingredients(network_config_1,
         graph_list1 = deepcopy(network_config_1)
     else:
         graph_list1 = dsl_parser.parse(network_config_1)
-    n1 = dsl_parser.list_to_graph(graph_list1)
     if isinstance(network_config_1, list):
         graph_list2 = deepcopy(network_config_2)
     else:
         graph_list2 = dsl_parser.parse(network_config_2)
-    n2 = dsl_parser.list_to_graph(graph_list2)
-    tree1 = core.alex_graph_to_tree(n1, exclude_types=["hyperparam"], naive=False)
-    # pprint(tree1)
-    tree2 = core.alex_graph_to_tree(n2, exclude_types=["hyperparam"], naive=False)
+    # n1 = dsl_parser.list_to_graph(graph_list1)
+    # n2 = dsl_parser.list_to_graph(graph_list2)
+    # tree1 = core.alex_graph_to_tree(n1, exclude_types=["hyperparam"], naive=False)
+    # tree2 = core.alex_graph_to_tree(n2, exclude_types=["hyperparam"], naive=False)
+
+    tree1 = param_count.ParamCount(graph_list1,
+                                   naive=False).annotate_tree()
+    tree2 = param_count.ParamCount(graph_list2,
+                                   naive=False).annotate_tree()
     _, operations = ted(tree1, tree2)
     # pprint(operations)
     if render_to is not None:
