@@ -140,7 +140,7 @@ def instantiate_node(name, label, value, meta, parent, children, descendants):
     node["descendants"] = deepcopy(descendants)
     node["parent"] = parent
     node["lmd"] = descendants[0] if len(descendants)>=1 else name
-    node["type"] = get_value_type(label)
+    node["type"] = get_value_type(value)
     node["meta"] = meta
     return node
 
@@ -452,9 +452,9 @@ def draw(tree, graph_path='example.png', annotation=dict(), dpi=800, size=5, lab
                 else:
                     label = str(tree[child][label_field])
                 node = pydot.Node(child,
-                                  label = label,
+                                  label=label,
                                   shape="box",
-                                  style = 'filled',
+                                  style='filled',
                                   fillcolor=color)
                 # if isinstance(tree[child]["meta"], dict):
                 #     if tree[child]["name"] != "root" and "block" in tree[child]["meta"]:
