@@ -271,11 +271,11 @@ class Regularizer(param_count.Ingredient):
         children = core.get_children(node["name"], annotated)
         args = dict()
         args[const.ALEX_ARG_INPUTS] = {"key": const.ALEX_ARG_INPUTS,
-                                       "value": node["input_names"],
+                                       "value": node["meta"]["position"]["inputs"],
                                        "ref": None,
                                        "type": IDENTIFIER,
                                        "str": value_to_kwarg_str("",
-                                                                 node["input_names"],
+                                                                 node["meta"]["position"]["inputs"],
                                                                  literal=True)}
         args[const.ALEX_ARG_NAME] = {"key": const.ALEX_ARG_NAME,
                                      "value": _name_strs_to_names(node["name"]),
@@ -375,11 +375,28 @@ class Value(param_count.Hyperparam):
 
     def generate_code(self, node, annotated, engine):
         if "padding" in node["parent"] and engine=="pytorch":
-            if node["value"] == "SAME":
-                _value = [1, 1]
-            elif node["value"] == "VALID":
-                # FIXME: calculate this
-                _value = [0, 0]
+            ingredient = annotated[node["meta"]["position"]["component"]]
+            if ingredient["value"] in ["conv", "max_pool2d"]:
+                if node["value"] == "SAME":
+                    _value = "same"
+                    # _value = [1, 1]
+                    # inputs = annotated[ingredient["meta"]["position"]["inputs"][0]]
+                    # input_shape = inputs["shape"]
+                    # h, w = input_shape[0], input_shape[1]
+                    strides = ingredient["meta"]["hyperparams"]["strides"]
+                    if strides[0]!=1 or strides[1]!=1:
+                        raise Exception("Pytorch does not support strided ops  for padding='same'")
+                    # if ingredient["value"] == "conv":
+                    #     k_h = ingredient["meta"]["hyperparams"]["filters"]["shape"]["kernel_size_h"]
+                    #     k_w = ingredient["meta"]["hyperparams"]["filters"]["shape"]["kernel_size_w"]
+                    # else:
+                    #     [k_h, k_w] = ingredient["meta"]["hyperparams"]["window_shape"]
+                    # padding_h_min = floor(((ingredient["shape"][0]-1)*strides[0] - h + k_h)/2)
+                    # padding_w_min = floor(((ingredient["shape"][1]-1)*strides[1] - w + k_w)/2)
+                    # _value = [padding_h_min, padding_w_min]
+                elif node["value"] == "VALID":
+                    # _value = [0, 0]
+                    _value = "valid"
         else:
             _value = node["value"]
         node = cache_fn(node=deepcopy(node),
@@ -640,7 +657,7 @@ class CodeGen(param_count.ParamCount):
         self.inline_index_translation = []
         self.inline_index_python = []
         self.blocks = {"param": {**const.ALL_PARAMS, **const.ALL_INITIALIZERS},
-                       "component": const.COMPONENT_BLOCK,
+                       "model": const.MODEL_BLOCK,
                        "optimizer": const.OPTIMIZER_BLOCK,
                        "loss": const.LOSS_BLOCK,
                        "scheduler": const.SCHEDULER_BLOCK,
@@ -650,26 +667,26 @@ class CodeGen(param_count.ParamCount):
                                         **self.blocks["scheduler"]}
             self.blocks["scheduler"] = {}
         self.filepaths = {"param": os.path.join(self.alex_cache_code_path, "_param_.py"),
-                          "component": os.path.join(self.alex_cache_code_path, "_component_.py"),
+                          "model": os.path.join(self.alex_cache_code_path, "_component_.py"),
                           "optimizer": os.path.join(self.alex_cache_code_path, "_optimizer_.py"),
                           "loss": os.path.join(self.alex_cache_code_path, "_loss_.py"),
                           "scheduler": os.path.join(self.alex_cache_code_path, "_scheduler_.py"),
                           "data": ""
         }
         self.alex_defs = {"param": [],
-                          "component": [],
+                          "model": [],
                           "optimizer": [],
                           "scheduler": [],
                           "loss": [],
                           "data": []}
         self.alex_code = {"param": [],
-                          "component": [],
+                          "model": [],
                           "optimizer": [],
                           "scheduler": [],
                           "loss": [],
                           "data": []}
         self.alex_inline = {"param": [],
-                            "component": [],
+                            "model": [],
                             "optimizer": [],
                             "scheduler": [],
                             "loss": [],
@@ -849,7 +866,7 @@ class CodeGen(param_count.ParamCount):
         optimizer_str = self.get_dl_code(block="optimizer",
                                          fn_name="get_optimizer",
                                          manual_args=["trainable_params", ])
-        component_str = self.get_dl_code(block="component",
+        component_str = self.get_dl_code(block="model",
                                          fn_name="model",
                                          manual_args=["input_data",
                                                       "trainable_params",
