@@ -6,8 +6,9 @@
 # Description:
 # ----------------------------------------------------------------------
 import numpy as np
-from math import floor
+from math import floor, ceil
 from pprint import pprint
+import traceback
 from copy import deepcopy
 from alex.alex import core, const, node_interface
 from alex.alex.annotator_interface import Annotator
@@ -15,6 +16,9 @@ from alex.engine import ns_alex
 
 
 class Ingredient(node_interface.Ingredient):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.transformation = None
 
     def get_shape(self, input_shape, *args):
         return input_shape
@@ -25,6 +29,57 @@ class Ingredient(node_interface.Ingredient):
                             core.get_children(name,
                                               annotated))))
 
+    def get_dimensions(self, node):
+        input_shape = node["meta"]["position"]["input_shape"]
+        if input_shape is not None:
+            input_shape = [input_shape] if not isinstance(input_shape[0], list) else input_shape  # FIXME: backward compatibility, remove (see same note below)
+        return [input_shape, # input shape
+                node["shape"]] # output shape
+
+    def get_transformation(self):
+        return self.transformation
+
+    def validate_connection(self, node):
+        transformations = self.get_transformation()
+        dims = self.get_dimensions(node)
+        if transformations is None:
+            return True
+        else:
+            valid = False
+            msg = ""
+            for trans in transformations:
+                if valid:
+                    return valid
+                try:
+                    if len(trans[0]) != len(dims[0]):
+                        msg = "Number of inputs mismatch %s (ingredient: %s, dim %s)" % (node["name"],
+                                                                                         node["value"],
+                                                                         str(dims))
+                        raise Exception(msg)
+                    elif len(list(filter(lambda x: len(x[0]) != len(x[1]),
+                                     zip(trans[0], dims[0]))))!=0:
+                        msg = "Tensor rank mismatch %s (ingredient: %s, dim: %s)" % (node["name"],
+                                                                                     node["value"],
+                                                                                     str(dims))
+                        raise Exception(msg)
+                    else:
+                        trans_ = [i for sub in trans[0] for i in sub] + trans[1]
+                        dims_ = [i for sub in dims[0] for i in sub] + dims[1]
+                        n = len(trans_)
+                        pattern_required = [trans_[i]==trans_[i+j] for i in range(n-1) for j in range(1, n-i)]
+                        pattern_data = [dims_[i]==dims_[i+j] for i in range(n-1) for j in range(1, n-i)]
+                    for r in pattern_required:
+                        if pattern_required and (not pattern_data):
+                            msg = "Tensor dimension mismatch" % node["name"]
+                            raise Exception(msg)
+                    valid = True
+                except:
+                    # traceback.print_exc()
+                    pass
+            if not valid:
+                traceback.print_exc()
+                raise Exception
+
 
 class Recipe(node_interface.Recipe):
 
@@ -37,6 +92,9 @@ class Recipe(node_interface.Recipe):
                             core.get_children(name,
                                               annotated))))
 
+    def validate_connection(self, node):
+        pass
+
 
 class Hyperparam(node_interface.Hyperparam):
 
@@ -49,12 +107,54 @@ class Hyperparam(node_interface.Hyperparam):
     def get_shape(self, input_shape, *args):
         return [0, ]
 
+    def validate_connection(self, node):
+        pass
 
 # ------------------------------------------------------------------------ #
-class Conv2D(Ingredient):
-
+class Dense(Ingredient):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self.transformation = [[[["a"]], ["b"]]]
+
+
+class CrossEntropy(Ingredient):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.transformation = [[[["a"], ["a"]], ["c"]]]
+
+    def get_shape(self, input_shape, name, annotated):
+        return [0]
+
+
+class Regularizer(Ingredient):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+    def get_shape(self, input_shape, name, annotated):
+        return [0]
+
+
+class Batchnorm(Ingredient):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.transformation = [[[["a", "b", "c"]], ["a", "b", "c"]]]
+
+
+class Add(Ingredient):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.transformation = [[[["a", "b", "c"], ["a", "b", "c"]], ["a", "b", "c"]],
+                               [[["a", "b"], ["a", "b"]], ["a", "b"]],
+                               [[["a"], ["a"]], ["a"]]]
+
+    def get_shape(self, input_shape, name, annotated):
+        return input_shape[0]
+
+
+class Conv2D(Ingredient):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.transformation = [[[["a", "b", "c"]], ["d", "e", "f"]]]
 
     def get_shape(self, input_shape, name, annotated):
         hyperparams = annotated[name]["meta"]["hyperparams"]
@@ -68,12 +168,14 @@ class Conv2D(Ingredient):
         h = input_shape[0]
         w = input_shape[1]
         if padding == "SAME":
-            padding = [1, 1] # FIXME
+            hout = ceil(h/strides[0])
+            wout = ceil(w/strides[1])
+            shape = [hout, wout, n_filters]
         elif padding == "VALID":
             padding = [0, 0]
-        shape = [floor((h + 2*padding[0] - dilation*(k_h-1) - 1)/strides[0] + 1),
-                 floor((w + 2*padding[1] - dilation*(k_w-1) - 1)/strides[1] + 1),
-                 n_filters]
+            shape = [floor((h + 2*padding[0] - dilation*(k_h-1) - 1)/strides[0] + 1),
+                     floor((w + 2*padding[1] - dilation*(k_w-1) - 1)/strides[1] + 1),
+                     n_filters]
         return shape
 
 
@@ -81,6 +183,8 @@ class MaxPool2D(Ingredient):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self.required_input_rank = 3
+        self.transformation = [[[["a", "b", "c"]], ["d", "e", "f"]]]
 
     def get_shape(self, input_shape, name, annotated):
         hyperparams = annotated[name]["meta"]["hyperparams"]
@@ -94,12 +198,14 @@ class MaxPool2D(Ingredient):
         h = input_shape[0]
         w = input_shape[1]
         if padding == "SAME":
-            padding = [1, 1] # FIXME
+            hout = ceil(h/strides[0])
+            wout = ceil(w/strides[1])
+            shape = [hout, wout, input_shape[-1]]
         elif padding == "VALID":
             padding = [0, 0]
-        shape = [floor((h + 2*padding[0] - dilation*(k_h-1) - 1)/strides[0] + 1),
-                 floor((w + 2*padding[1] - dilation*(k_w-1) - 1)/strides[1] + 1),
-                 input_shape[-1]]
+            shape = [floor((h + 2*padding[0] - dilation*(k_h-1) - 1)/strides[0] + 1),
+                     floor((w + 2*padding[1] - dilation*(k_w-1) - 1)/strides[1] + 1),
+                     input_shape[-1]]
         return shape
 
 
@@ -181,6 +287,9 @@ class Flatten(Ingredient):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self.required_input_rank = None
+        self.transformation = [[[["a", "b", "c"]], ["d"]],
+                               [[["a", "b"]], ["d"]]]
 
     def get_shape(self, input_shape, *args):
         return [np.prod(np.asarray(input_shape)), ]
@@ -206,27 +315,37 @@ class Label(Ingredient):
 
 def nodes(node):
     value = node["value"]
-    _nodes = {"data": Data,
-              "label": Label,
-              "conv": Conv2D,
-              "max_pool2d": MaxPool2D,
-              "flatten": Flatten,
-              "filters": Conv2DFilters,
-              "weights": DenseWeights,
-              "bias": DenseBias,
-              "means": BatchnormMean,
-              "vairance": BatchnormVariance,
-              "offset": BatchnormOffset,
-              "scale": BatchnormOffset,
-              "ingredient": Ingredient,
-              "hyperparam": Hyperparam,
-              "recipe": Recipe}
+    # TODO: group ingredient by block
+    nodes_ingredient = {"ingredient": Ingredient,
+                        "data": Data,
+                        "cross_entropy": CrossEntropy,
+                        "label": Label,
+                        "dense": Dense,
+                        "add": Add,
+                        "batch_normalize": Batchnorm,
+                        "regularizer_l2": Regularizer,
+                        "conv": Conv2D,
+                        "max_pool2d": MaxPool2D,
+                        "flatten": Flatten}
+    nodes_hyperparam = {"hyperparam": Hyperparam}
+    nodes_param = {"filters": Conv2DFilters,
+                   "weights": DenseWeights,
+                   "bias": DenseBias,
+                   "means": BatchnormMean,
+                   "vairance": BatchnormVariance,
+                   "offset": BatchnormOffset,
+                   "scale": BatchnormOffset}
+    nodes_recipe = {"recipe": Recipe}
+
+    _nodes = {**nodes_hyperparam,
+              **nodes_ingredient,
+              **nodes_param,
+              **nodes_recipe}
     if value not in _nodes:
         value = node["type"]
     return _nodes[value](node["value"])
 
 
-
 class ParamCount(Annotator):
 
     def __init__(self, *args, **kwargs):
@@ -246,19 +365,20 @@ class ParamCount(Annotator):
         node = deepcopy(node)
         name = node["name"]
         input_nodes = self.get_input_nodes(name, self.annotated)
-        input_names = self.get_input_names(name, self.annotated)
-        # FIXME: for regularization
         if input_nodes is not None and input_nodes[0] is None:
             input_nodes = None
         if input_nodes is not None:
-            input_shape = input_nodes[0]["shape"]
+            input_shape = []
+            for _input_node in input_nodes:
+                input_shape.append(_input_node["shape"])
+            if len(input_shape) == 1:
+                input_shape = input_shape[0] # FIXME: backward compatibility, remove
             node["shape"] = nodes(node).get_shape(input_shape,
                                                   name,
                                                   self.annotated)
             if node["value"] == "channels":
                 node["value"] = input_shape[-1]
                 node["name"] = input_shape[-1]
-                # print(input_shape, name, node["shape"])
         else:
             input_shape = None
             if name in self.components:
@@ -274,11 +394,11 @@ class ParamCount(Annotator):
         else:
             inputs = list(map(lambda x: x["name"], input_nodes))
         node["input_nodes"] = inputs
-        node["input_names"] = input_names
-        node["input_shape"] = input_shape
+        node["meta"]["position"]["input_shape"] = input_shape
         node["ancestor"] = core.get_ancestor_ingredient_node(node, self.tree)
         if node["ancestor"]["name"] in self.components:
             node["dtype"] = self.components[node["ancestor"]["name"]]["meta"]["dtype"]
         else:
             node["dtype"] = None
+        nodes(node).validate_connection(node)
         return node
